==> asksuite-core-2.2.1.tgz: package/translator/translate-object.js <==
const {
    asyncMapValuesDeep,
    omitAttributesDeep
} = require('./util');

const _ = require('lodash');
const md5 = require('md5');
const request = require('request-json');

const createRedisClient = require('../util/redis');

const languageMap = {
    "pt-br": "ptBR",
    "en": "enUS",
    "es": "es"
};

module.exports = configuration => {
    const redis = createRedisClient(configuration.redis);

    const getTranslation = async (text, languageFrom, languageTo, customId) => {
        if(languageTo === languageFrom) return text;

        const client = request.createClient(configuration.url);

        let path = `translate/${languageTo}/${languageFrom}`;
        if (customId) {
            path += `/${customId}`;
        }

        const translateResponse = await client.post(path, [text]);
        return translateResponse.body[0];
    };

    const getCachedTranslation = async (hash, languageProperty, customId) => {
        const customTranslation = await redis.getValue(`${customId}:${hash}`);
        const globalTranslation = await redis.getValue(hash);

        return _.get(customTranslation, languageProperty) || _.get(globalTranslation, languageProperty);
    };

    const notNeedsTranslate = (text, attribute, removedAttributes) =>
        _.includes(removedAttributes, attribute) || !_.isString(text) || _.isEmpty(text);

    const translate = async (text, attribute, removedAttributes, languageFrom, languageTo, customId) => {
        if(notNeedsTranslate(text, attribute, removedAttributes)) return text;

        const hash = md5(text);
        const languageProperty = _.get(languageMap, languageTo);

        const cachedTranslation = await getCachedTranslation(hash, languageProperty, customId);

        if (cachedTranslation) {
            return cachedTranslation || text;
        }

        const translation = await getTranslation(text, languageFrom, languageTo, customId);

        return translation || text;
    };

    const translateObject = (object, languageFrom, languageTo, removedAttributes, customId) => {
        const contextTranslate = (text, attribute) => translate(text, attribute, removedAttributes, languageFrom, languageTo, customId);
        return asyncMapValuesDeep(object, contextTranslate);
    };

    return translateObject;
};

==> asksuite-core-2.5.0.tgz: package/translator/translate-object.js <==
const {
    asyncMapValuesDeep,
    omitAttributesDeep
} = require('./util');

const _ = require('lodash');
const md5 = require('md5');
const request = require('request-json');

const createRedisClient = require('../util/redis');

const languageMap = {
    "pt-br": "ptBR",
    "en": "enUS",
    "es": "es"
};

module.exports = configuration => {
    const redis = createRedisClient(configuration.redis);

    const getTranslation = async (text, languageFrom, languageTo, customId) => {
        if(languageTo === languageFrom) return text;

        const client = request.createClient(configuration.url);

        let path = `translate/${languageTo}/${languageFrom}`;
        if (customId) {
            path += `/${customId}`;
        }

        const translateResponse = await client.post(path, [text]);
        return translateResponse.body[0];
    };

    const getCachedTranslation = async (hash, languageProperty, customId) => {
        const customTranslation = await redis.getValue(`${customId}:${hash}`);
        const globalTranslation = await redis.getValue(hash);

        return _.get(customTranslation, languageProperty) || _.get(globalTranslation, languageProperty);
    };

    const notNeedsTranslate = (text, attribute, removedAttributes, languageFrom, languageTo) => {
        const notNeeds = _.includes(removedAttributes, attribute) || !_.isString(text) || _.isEmpty(text);
        if (notNeeds) {
            return notNeeds;
        }

        const normalizeLanguage = (lang) => lang.toLowerCase().replace("-", "_").split("_")[0];
        return normalizeLanguage(languageFrom) === normalizeLanguage(languageTo);
    };

    const translate = async (text, attribute, removedAttributes, languageFrom, languageTo, customId) => {
        if(notNeedsTranslate(text, attribute, removedAttributes, languageFrom, languageTo)) return text;

        const hash = md5(text);
        const languageProperty = _.get(languageMap, languageTo);

        const cachedTranslation = await getCachedTranslation(hash, languageProperty, customId);

        if (cachedTranslation) {
            return cachedTranslation || text;
        }

        const translation = await getTranslation(text, languageFrom, languageTo, customId);

        return translation || text;
    };

    const translateObject = (object, languageFrom, languageTo, removedAttributes, customId) => {
        const contextTranslate = (text, attribute) => translate(text, attribute, removedAttributes, languageFrom, languageTo, customId);
        return asyncMapValuesDeep(object, contextTranslate);
    };

    return translateObject;
};
